function [num,den,bias,um,ym,potencia]=blms2(u,y,AR,MA,lambda,bias,p,q)
%        [num,den,bias,um,ym,potencia]=blms2(u,y,AR,MA,lambda,bias,p,q)
%
% BLMS2: Batch LMS
%
% ENTRADAS:
%      u: Vector de entradas (R x Q)
%      y: Vector de salidas  (1 x Q)
%     AR: Orden del denominador (Autorregresive)
%     MA: Orden del numerador   (Moving Average)
% lambda: Factor "weight decay" para la pseudoinversa (1 x 1)
%   bias: si se usa esta entrada, aade un termino de bias
%      p: tamao de cada ventana (1 x 1)
%      q: distancia en muestras entre ventanas (1 x 1)
%   
% SALIDAS:
%    num: coeficientes del numerador (MA+1 x Qd)
%    den: coeficientes del denominador (AR + 1 x Qd)
%   bias: valor del bias (1 x Qd)
%     um: valor medio de las entradas en cada buffer, (R x Qd)
%     ym: valor medio de las salidas  en cada buffer, (1 x Qd)
% 
%   Nota: Qd es el numero de buffers resultantes con el overlapping
%   indicado en p y q



if nargin == 4
    lambda = 0.00001;
    bias = 0;
    p = 100;
    q = 1;
elseif nargin == 5
    bias = 0;
    p = 100;
    q = 1;
elseif nargin == 6
    p = 100;
    q = 1;
end;    


[uf,uc]=size(u);


[x,y]=tddata(u,y,AR,MA);



N = size(x,2);


longitud = length(p+1:q:N);

for j = 1:uf
    num{j} = zeros(MA+1,longitud);
end
den  = zeros(AR+1,longitud);

% OJO!!! BORRADO 12/01/2009... No s por qu estaba esto que pona el bias a 0
% bias = zeros(1,longitud);


if bias==0
    i = 0;
    for k = p+1:q:N
        i = i+1;
        T = linreg(y(:,k-p:k),x(:,k-p:k),lambda);
        for j = 1:uf
            num{j}(:,i) = T( ((0:MA)*uf) + j )';
        end
        den(:,i) = [1 -T(end-AR+1:end)]';
        bias(i) = 0;
    end
else
    x = [x;ones(1,size(x,2))];
    i = 0;
    for k = p+1:q:N
        i = i+1;
        T = linreg(y(:,k-p:k),x(:,k-p:k),lambda);
        for j = 1:uf
            num{j}(:,i) = T( ((0:MA)*uf) + j )';
        end
        den(:,i) = [1 -T(end-AR+1-1:end-1)]';
        bias(i) = T(end);
    
        % Calcula la potencia del ruido (sigma^2_w)  en el caso de modelos AR
        % puros
        if (sum(abs(u))==0) && (MA==0)
            R = ifft(abs(fft(y(k-p:k),2^nextpow2(2*(p+1)-1))).^2)/(p+1);             % Calculo de la secuencia de autocorrelacion para cada ventana
            d = toeplitz(R(1:length(den(:,i))))*den(:,i);       % Calculo de la potencia a partir de la autocorrelacion (Proakis pag. 866)
            potencia(i) = d(1);
        end
            
    end
end



if uf==1
    num = num{:};
end



if nargout>=4
    i = 0;
    for k = p+1:q:N    
        i = i+1;
        for j = 1:uf
            um(j,i) = mean(x(j,k-p:k));
        end    
        ym(1,i) = mean(y(k-p:k));
    end
end
