function [smap,MSE] = bsom_din(yd,ud,q,smap,epochs,Nc,ordertype)


% Copyright (c) 2009 Ignacio Daz Blanco
% Area de Ingeniera de Sistemas y Automtica. 
% Universidad de Oviedo.


if nargin<7
    ordertype = 'model';
end


if ~isfield(smap,'wq')
    % Initialize the model part
    aux = inisom(ud,smap.dims);
    smap.w = aux.w;
    smap.R = size(ud,1);
    for k = 1:smap.R
        smap.featnames{k} = sprintf('T(%d)',k);
        smap.limits(k,:) = [-5,5];
    end

    % Initialize the data part
    aux = inisom(q,smap.dims);
    smap.wq = aux.w;
end


Q   = size(ud,2);
S   = smap.S;

% Neighbourhood selection
lnc = length(Nc);
if lnc==1
    neigh = logspace(log10(max([cat(1,smap.dims{:})]/3)),log10(Nc),epochs);
elseif lnc==2
    neigh = logspace(log10(Nc(1)),log10(Nc(2)),epochs);
elseif lnc>2
    if lnc~=epochs
        error('length of neighborhood vector does not match number of epochs');
    end;
    neigh = Nc;
end;



if strncmp(ordertype,'data',2)
    disp('Data ordering...');
elseif strncmp(ordertype,'model',2)
    disp('Model ordering...');
end

for ke = 1:epochs

    % ESTIMATE yd USING MODELS
    yest = smap.w*ud;                         % Estimate Q input data points using S models (S x Q)


    err_data  = matdist(smap.wq',q);          % data  ordering: distance from all codebook vectors to all pts  (S x Q)
    err_model = (repmat(yd,S,1) - yest).^2;   % model ordering: estimation error of all models to all pts (S x Q)

    if strncmp(ordertype,'data',2)
        err = err_data;
        wn = mapminmax(smap.wq');
    elseif strncmp(ordertype,'model',2)
        err = err_model;
        wn = mapminmax(smap.w');
    end

    

    % BEST MATCHING UNIT
    [qerr,bmu] = min(err);


    % NEIGHBORHOOD FUNCTION
    hci = exp(-(double(smap.dis(:,bmu)) + 15*matdist(wn,wn(:,bmu))).^2/(2*neigh(ke)^2))+0.00000;


    % MODEL ADAPTATION
    % compute the models using weighted least squares
    for k = 1:S
        [smap.w(k,:),smap.rmse(k)] = linreg(yd,ud,0.0000001,hci(k,:));
    end

    


    % DATA  ADAPTATION
    smap.wq = (hci*q')./(sum(hci,2)*ones(1,size(q,1)));



    % COMPUTE AND DISPLAY PERFORMANCE
    mse_data(ke)  = mean(min(err_data));
    mse_model(ke) = mean(min(err_model)); 
    if ~rem(ke,epochs/10)
        fprintf('Epoca: %d,\t Vecindad: %f,\t mse (model): %f\t mse (data): %f \n',ke,neigh(ke),mse_model(ke),mse_data(ke));
    end


end

smap.err = err;

