function u = datagrid(limits,Npoints);

% DATAGRID Generates points of an N-D grid with specified limits
%
%          u = datagrid(limits,Npoints)
%
% limits: (Rx2) matrix with the following structure
%                      [low_limit_1, high_limit_1;
%                       low_limit_2, high_limit_2;
%                       ...        , ...         ;
%                       low_limit_R, high_limit_R]
%
% Npoints: (optional) A vector specifying the number 
%          of points in the grid for each dimension. A scalar can be
%          used specifying a single value for all dimensions.
%          If not specified, a suitable value is chosen.
%
%


%   Copyright (c) 2007, by 
%   Grupo de Supervisin y Diagnstico de Procesos Industriales
%   Area de Ingeniera de Sistemas y Automtica
%   Universidad de Oviedo
%   Contributed files may contain copyrights of their own.
%   
%   UniOviSOM toolbox is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.
% 
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
% 
%   You should have received a copy of the GNU General Public License
%   along with this program; if not, write to the Free Software
%   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.


if nargin~=0
    [R,S] = size(limits);
else
    R = 2; S = 2;
    limits  = [-10 10; -10 10];
    Npoints = [50,50];
end

if nargin==1
    Npoints = repmat(ceil(3000^(1/R)),[R,1]);
elseif length(Npoints)==1
    Npoints = repmat(Npoints,[R,1]);
end

if S~=2
    error('limits parameter must be an Rx2 matrix [low_1,hgh_1;low_2,hgh2;...]');
end

for k = 1:R
    lim{k} = linspace(limits(k,1),limits(k,2),Npoints(k));
end


u = rectop(lim{:},'idx');


