% Demo001 A SIMPLE EXAMPLE OF SOM TRAINING
%
% This example includes the following features:
%   - Generation of a training data set
%   - Initialization and training of a 2D SOM object
%   - Visualization of the input and output space
%   - Visualization of the SOM planes
%   - Computation of the SOM interneuron distance map
%   - Computation of the activation map generated by a labelled data set
%   - Visualization of the previous distance and activation maps

%   Copyright (c) 2007, by 
%   Grupo de Supervisin y Diagnstico de Procesos Industriales
%   Area de Ingeniera de Sistemas y Automtica
%   Universidad de Oviedo
%   Contributed files may contain copyrights of their own.
%   
%   UniOviSOM toolbox is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.
% 
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
% 
%   You should have received a copy of the GNU General Public License
%   along with this program; if not, write to the Free Software
%   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.


% Generate a training set of data points in the input space
p = [randn(3,100)-5 randn(3,100)+5 randn(3,200)+[1;0;0]*ones(1,200)];

% Plot the training set
figure(1);
plotp(p);

% Initialize a 2-D SOM object
som = inisom(p,{20,20});

% Plot the initiazlized SOM along with the input data
figure(2);
plotsom(p,som);

% Train the SOM with the data
som = bsom(p,som);      % Let uniovisom choose number of epochs and neighbourhood

% Plot the trained SOM
figure(3);
plotsom(p,som);

% Plot the SOM and the data in the input and output space
figure(4);
plotsom(p,som,'both');

% Plot the SOM planes
figure(5);
planes(som);

% Plot the distance map and the activation map of the first cloud of data
figure(6);
dist = somdist(som);
actv = activation(p(:,1:100),som);
planes(som.pos,[dist;actv],{'Distance Map','Activation Map'});
