% demo_grnn_2D: 2D GRNN REGRESSION DEMO

%   Copyright (c) 2007, by 
%   Grupo de Supervisin y Diagnstico de Procesos Industriales
%   Area de Ingeniera de Sistemas y Automtica
%   Universidad de Oviedo
%   Contributed files may contain copyrights of their own.
%   
%   UniOviSOM toolbox is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.
% 
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
% 
%   You should have received a copy of the GNU General Public License
%   along with this program; if not, write to the Free Software
%   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

figure(1);
clf;

clf;
close all;

% create 300 2D points
xi = rands(2,300);

% compute the elevation according to a known nonlinear model
yi = sinc(4*(xi(1,:).^2+xi(2,:).^2));

% plot the resulting 3D points
figure(1);
clf;
plotp([xi;yi],'k.',30);

% test on a square interval on the 2D domain using a regular grid
u = rectop(linspace(-1,1,50),linspace(-1,1,50),'idx');

% width factor
sigma = 0.5;

% train the model
grnn = grnntra(yi,xi,sigma,1e-7);

% predict the elevation using the trained model
yest = grnnsim(u,grnn);

% plot the results (use rotate 3D in the figure to see this better)
hold on;
plotp([u;yest],'r.');
axis([-1,1,-1,1]);
hold off;






