% demoresiduals.m

%   Copyright (c) 2007, by 
%   Grupo de Supervisin y Diagnstico de Procesos Industriales
%   Area de Ingeniera de Sistemas y Automtica
%   Universidad de Oviedo
%   Contributed files may contain copyrights of their own.
%   
%   UniOviSOM toolbox is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.
% 
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
% 
%   You should have received a copy of the GNU General Public License
%   along with this program; if not, write to the Free Software
%   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

% LOAD DATA OF TEST RIG
load dataicann;



%%%%%%%%%%%%%%%%%%%% FEATURE EXTRACTION PROCESS  %%%%%%%%%%%%%%%%%%%%%

% GENERATE A COMPLEX SIGNAL WITH VIBRATION DATA (ORBIT)
fm = 5000;
for k = 1:length(z),
   zv{k}=[z{k}(:,2)+j*z{k}(:,3)];
end

% GENERATE PARK'S VECTOR
a=exp(j*2*pi/3);
for k = 1:length(z),
   zc{k}=[z{k}(:,4)+a*z{k}(:,5)+a^2*(-z{k}(:,4)-z{k}(:,5))];
end



% FREQUENCIES OF INTEREST
vfrecs = [25 100 -25 -100];
cfrecs = [50 -50];
% vfrecs = [25 100 -25 -100 200 -200 300 -300];
% cfrecs = [50 -50 150 -150];


% FILES TO BE USED USING FOR TRAINING AND TEST
trnlabels = {'cap0ohm','cap20ohm','asim0g','asim0gfallor'};
tstlabels = {'capvarohm2.dt0'};
ktrn = strnmatch(trnlabels,nom);
ktst = strnmatch(tstlabels,nom);
%ktrn   = [3 6 1 2]; 
%ktst   = [9];


% TRAINING SET GENERATION
nfft = 2048;
overlap = 0.98;
disp('Training data sets:');
nom(ktrn)',
[pvtrn,tvtrn,ev]  = excar(zv([ktrn]),vfrecs,5*ones(1,length(vfrecs)),fm,nfft,overlap,{'XY-Plane'});
[pctrn,tctrn,ec]  = excar(zc([ktrn]),cfrecs,5*ones(1,length(cfrecs)),fm,nfft,overlap,{'Park Vector'});
[pntrn,pntrn_npar] = normalize_data('mnmx',[pvtrn;pctrn]);

% TEST SET GENERATION
disp('Test data sets:');
nom(ktst)',
[pvtst,tvtst,ev]=excar(zv([ktst]),vfrecs,5*ones(1,length(vfrecs)),fm,nfft,overlap,{'XY-Plane'});
[pctst,tctst,ec]=excar(zc([ktst]),cfrecs,5*ones(1,length(cfrecs)),fm,nfft,overlap,{'Park Vector'});
pntst = normalize_data('apply',[pvtst;pctst],pntrn_npar);

% MAKING LABELS
evc = [ev ec];


%%%%%%%%%%%%%%%%%%%%%% LEARNING PROCESS %%%%%%%%%%%%%%%%%%%%%%%%%%
[R,Q] = size(pntrn);

pn = pntrn(:,1:Q/4);        % Normal condition data...
som = inisom(pn,{20,20});   % Train a SOM with normal condition data (could be also an MLP or k-means)
som = bsom(pn,som);         %
    
[pr,res] = fproj(pntrn,som);    % Get the values of the residuals vector


figure(1);
imagesc(res);                   % Plot the evolution of residuals vector along time
text(5*ones(1,R),1:R,evc);      % Plot labels of each feature
title('Residuals of normal and fault conditions');


% Take subsets of the residuals corresponding to different process conditions
range = 1:Q/4;
normal = res(:,range+0*Q/4);  
fault1 = res(:,range+1*Q/4);
fault2 = res(:,range+2*Q/4);
fault3 = res(:,range+3*Q/4);

rangehalf1 = 1:round(Q/64);              % Reserve half of the data as training set for the classifier
rangehalf2 = setdiff(range,rangehalf1);  % The rest is reserved for test set.

normaltrn = normal(:,rangehalf1);
fault1trn = fault1(:,rangehalf1);
fault2trn = fault2(:,rangehalf1);
fault3trn = fault3(:,rangehalf1);

normaltst = normal(:,rangehalf2);
fault1tst = fault1(:,rangehalf2);
fault2tst = fault2(:,rangehalf2);
fault3tst = fault3(:,rangehalf2);



% Outputs of the GRNN to perform classification
outnormal = [1;0;0;0]*ones(1,size(normaltrn,2));
outfault1 = [0;1;0;0]*ones(1,size(fault1trn,2));
outfault2 = [0;0;1;0]*ones(1,size(fault2trn,2));
outfault3 = [0;0;0;1]*ones(1,size(fault3trn,2));

% Train GRNN with residuals corresponding to different process conditions
grnn = grnntra([outnormal,outfault1,outfault2,outfault3],[normaltrn,fault1trn,fault2trn,fault3trn],.4);
out  = grnnsim(res,grnn);

figure(2);
plot(out');

% Obtain the residuals of the variable condition
[varpr,varres]=fproj(pntst,som);
varout = grnnsim(varres,grnn);
figure(3);
plot(varout');








% DATA TO PERFORM ROC ANALYSIS
positivedata{1} = normaltst;
positivedata{2} = fault1tst;
positivedata{3} = fault2tst;
positivedata{4} = fault3tst;

negativedata{1} = [fault1tst,fault2tst,fault3tst];
negativedata{2} = [normaltst,fault2tst,fault3tst];
negativedata{3} = [normaltst,fault1tst,fault3tst];
negativedata{4} = [normaltst,fault1tst,fault2tst];


classifiername{1} = 'Normal';
classifiername{2} = 'Fault1';
classifiername{3} = 'Fault2';
classifiername{4} = 'Fault3';


    
x    = linspace(-2,2,1000);
bins = linspace(-2,2,100);
dx   = sqrt(matdist(x,bins)); 

sigma = 0.002;

for k = 1:4,
    aux = grnnsim(positivedata{k},grnn);
    outpositive{k} = aux(k,:);
    histpositive{k} = hist(outpositive{k},bins);
    cumhistpositive{k} = cumsum(histpositive{k})/length(outpositive{k});

    aux = grnnsim(negativedata{k},grnn);
    outnegative{k} = aux(k,:);
    histnegative{k} = hist(outnegative{k},bins);
    cumhistnegative{k} = cumsum(histnegative{k})/length(outnegative{k});
    
    % Parzen kernel estimation of pdf's
    positivepdf{k} = histpositive{k}*normpdf(dx,0,0.02)'/sum(histpositive{k}); 
    negativepdf{k} = histnegative{k}*normpdf(dx,0,0.02)'/sum(histnegative{k}); 
    
    % cdf's are obtained by integration of the pdf's
    positivecdf{k} = cumsum(positivepdf{k})*(x(2)-x(1));
    negativecdf{k} = cumsum(negativepdf{k})*(x(2)-x(1));
        
end

figure(4)
dbins = bins(2)-bins(1);
for k = 1:4
    subplot(2,2,k);
    bar(bins,histpositive{k},'r'); hold on;
    bar(bins,histnegative{k},'b');
    plot(x,positivepdf{k}*sum(histpositive{k})*dbins,'r')
    plot(x,negativepdf{k}*sum(histnegative{k})*dbins,'b'); hold off;
    legend('Negative (estim)','Positive (estim)','Negative (sample)','Positive (sample)');
%     plot(x,negativepdf{k},x,positivepdf{k},bins,histnegative{k},'.:',bins,histpositive{k},'.:');
%     legend('Negative (estim)','Positive (estim)','Negative (sample)','Positive (sample)');
    title(['pdf ' classifiername{k}]);
end

figure(5)
for k = 1:4
    subplot(2,2,k);
    plot(x,negativecdf{k},x,positivecdf{k},bins,cumhistnegative{k},'.',bins,cumhistpositive{k},'.');
    legend('Negative (estim)','Positive (estim)','Negative (sample)','Positive (sample)');
    title(['cdf ' classifiername{k}]);
end


figure(6)
for k = 1:4
    subplot(2,2,k);
    plot(1-negativecdf{k},1-positivecdf{k},1-cumhistnegative{k},1-cumhistpositive{k},'.');
    legend('estim','sample');
    title(['ROC: ' classifiername{k}]);
end





