function [Ptot,t,etiq,tramos,aux] = excar(y,frecs,anchos,fm,nfft,solap,Nombres)
% [Ptot,t,etiq,tramos] = excar(y,frecs,anchos,fm,nfft,solap,Nombres)
%
% ENTRADAS
% {y}:     Cell array with R data records each one consisting in a data
%          matrix [NxM] (N samples, M channels).
% frecs:   Vector (1xK) with a central frequency (in Hz) for each band
% anchos:  Vector (1xK) with a bandwidth value (in Hz) for each band
% fm:      Sampling frequency in Hz (1x1)
% nfft:    Size of the overlapping windows (1x1)
% solap:   Window overlapping (in p.u. with respect to nfft) (1x1)
% Nombres: Names of the features corresponding to the rows of data matrices {cell array}
%
% OUTPUTS
% p:       Data matrix containing the computed spectral features along time
% t:	   Vector with times corresponding to each column of p
% etiq:    Labels with the names of each computed feature 
%
% Description:
%    This function divides signal y into overlaped windows of size nfft,
%    and computes the FFT algorithm, taking the RMS value of the signal content  
%    in the bands specified by frecs and anchos for each variable in each time window.

%   Copyright (c) 2007, by 
%   Grupo de Supervisin y Diagnstico de Procesos Industriales
%   Area de Ingeniera de Sistemas y Automtica
%   Universidad de Oviedo
%   Contributed files may contain copyrights of their own.
%   
%   UniOviSOM toolbox is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.
% 
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
% 
%   You should have received a copy of the GNU General Public License
%   along with this program; if not, write to the Free Software
%   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.


if nargin == 4
    nfft   = 4096;
    solap  = 0.8;
end

nsolap = floor(nfft*solap);

NumRegistros = size(y,2);
NumCanales   = size(y{1},2);

Ptot=[];
for Registro = 1:NumRegistros
    P = [];
    disp(['excar: Procesando Registro ' num2str(Registro) ':']);
    for Canal = 1:NumCanales
        disp(['excar: Procesando Canal ' num2str(Canal) ':']);
        [ymat,idx] = reforma(y{Registro}(:,Canal),nsolap,nfft);
        aux = idx;        
        
        UsarVentana=1;
        if UsarVentana
            rmshanning = 0.61237274188193;
            % Con ventana de Hanning
            Y = (1/rmshanning)*fft(ymat.*(hanning(nfft)*ones(1,size(ymat,2))))/nfft;
            
        else                        
            % Sin ventana de Hanning
            Y = fft(ymat)/nfft;
        end
        
        t = idx(1,:)/fm;
        
        
        
        f = round(frecs *nfft/fm);
        a = round(anchos*nfft/fm/2);
        
        f_inf = f-a;
        f_sup = f+a;
        
        p=[];
        for k = 1:length(frecs)
            idx = f_inf(k):f_sup(k);
            if isreal(ymat)                     % Si la seal es real                                                                
                idx = [idx -idx];               % Generar un conjunto de frecuencias 'espejo'
                                                % y operar exactamente igual...
            end
            rango_f = mod(idx,nfft)+1;
            rango_f = unique(rango_f);          % El unique elimina duplicidades (solapamientos de rangos de frecuencia)
            Yaux = abs(Y(rango_f,:));   
            p(k,:) = sqrt(sum(Yaux.^2,1));      % Valor RMS de los armonicos (raiz de la suma de cuadrados de val. eficaces)
        end
        P = [P;p];
    end
    ini_idx = size(Ptot,2)+1;
    fin_idx = size(Ptot,2)+size(P,2);
    tramos(Registro,:) = [ini_idx,fin_idx];
    Ptot = [Ptot P];
end
% disp('... clculo finalizado');


if nargin==7
    i=0;
    for k=1:NumCanales
        for j=1:length(frecs)
            i=i+1;
            etiq{i} = [Nombres{k} '@' num2str(frecs(j)) 'Hz'];
        end
    end
end


