function Xf = filtrafft(X,fc);
% FILTRAFFT Filters data using FFT
%
%   Xf = filtrafft(X,fc);
%
%    X: Data matrix (NxR)
%   fc: Cutoff frequency in per unit of sample frequency
%
% OUTPUTS
%   Xf: Filtered signal (NxR)
%
%

%   Copyright (c) 2007, by 
%   Grupo de Supervisin y Diagnstico de Procesos Industriales
%   Area de Ingeniera de Sistemas y Automtica
%   Universidad de Oviedo
%   Contributed files may contain copyrights of their own.
%   
%   UniOviSOM toolbox is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.
% 
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
% 
%   You should have received a copy of the GNU General Public License
%   along with this program; if not, write to the Free Software
%   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

if fc >= 0.5
   error('La frecuencia de corte excede la frecuencia de Shannon...');
end

N       = size(X,1);
NumFeat = size(X,2);
Nc      = round(N*fc);

Y  = fft(X);
H  = hanning(2*Nc-1);
Yf = Y.*([ones(Nc,1).*H(Nc:end); zeros(N-(2*Nc-1),1); ones(Nc-1,1).*H(1:Nc-1)]*ones(1,NumFeat));
Xf = real(ifft(Yf));


