function [p,t] = getpoints(siz)

% GETPOINTS: Get points from mouse clicks
%
% [p,t] = getpoints(siz)
%
% siz: size of the capture area. Can be either
%      a) a scalar: then a centered squared area is taken [-siz siz -siz siz]
%      b) a 2 elem vec: then a centered rectangular area is taken [-siz(1) siz(1) -siz(2) siz(2)]
%      c) a 4 elem vec: then an arbitrary rectangular area is taken [siz(1) siz(2) siz(3) siz(4)]
% p: Matrix (2xQp) with points generated with the left button
% t: Matrix (2xQt) with points generated with the right button
%

%   Copyright (c) 2007, by 
%   Grupo de Supervisin y Diagnstico de Procesos Industriales
%   Area de Ingeniera de Sistemas y Automtica
%   Universidad de Oviedo
%   Contributed files may contain copyrights of their own.
%   
%   UniOviSOM toolbox is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.
% 
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
% 
%   You should have received a copy of the GNU General Public License
%   along with this program; if not, write to the Free Software
%   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.


if nargin==1
    if length(siz)==1
        axes = siz*[-1 1 -1 1];
    elseif length(siz)==2
        axes = [siz(1)*[-1 1] siz(2)*[-1 1]];
    else
        axes = siz;
    end        
else
    axes = [-10 10 -10 10];
end


figure(1);
clf;
axis(axes);
grid on;
p = [];
t = [];
while 1
    [x,y,b] = ginput(1);
    if isempty(b)
        break;
    elseif b==1
        p = [p [x;y]];
        plot(p(1,:),p(2,:),'b.','markersize',10);
        hold on;
    elseif b==3
        t = [t [x;y]];
        plot(t(1,:),t(2,:),'r.','markersize',10);
        hold on;
    elseif b==2
        break
    end
    axis(axes);
    grid on;
end
hold off;
