function [T,RMSE,rho] = linreg(y,x,lambda,pesos)
% LINREG: Linear regression
%
%         T = linreg(y,x,lambda,pesos)
%
% Inputs
%      x: Input  data matrix with vectors by columns (Rx,N)
%      y: Output data matrix with vectors by columns (Ry,N)
% lambda: Regularization parameter (default = 0)
%  pesos: Pesos asignados a cada elemento (1xN)
%
% Outputs
%      T: Matrix (Ry,Rx)
%
% Obtains the least squares approximation of a matrix T 
% such that 
%
%      y = T*x

% Copyright (c) 2000-2002 by
% Grupo de Visualizacin y Diagnstico de Procesos Complejos.
% Area de Ingeniera de Sistemas y Automtica. 
% Universidad de Oviedo.


if nargin == 2
    lambda = 0;
end


N  = size(x,2);
Rx = size(x,1);
Ry = size(y,1);

I = eye(Rx);

% T = pinv(x,0.000001)'*y';
T = inv(x*x'+lambda*I)*x*y';
T = T';



% AADIDO 2006-05-12
if nargin==4
    % ELIMINADO 2009-11-22: MUY LENTO
    % T = inv(x*diag(pesos)*x'+lambda*I)*x*diag(pesos)*y';
    xpesos = x.*repmat(pesos,Rx,1);
    T = inv(xpesos*x'+lambda*I)*xpesos*y';
    T = T';
end    
% F_AADIDO




if nargout>=2
    errores=y-T*x;
    MSE=sum(sum(errores.^2))/prod(size(errores));
    RMSE = sqrt(MSE);
end

if nargout==3
    M = x*x';
    rho = rank(M,lambda);
end



