function x=loadmpx(mpx,inicio,longitud)
% LOADMPX    Cargar datos de un archivo .MPX de MAPREX.
%
%          x=loadmpx(mpx,inicio,longitud)
%            x:        estructura con toda la informacin del archivo.
%            inicio:   inicio de los datos muestreados que cargar.
%            longitud: nmero de datos muestreados que se cargan.

tam_int=4;
tam_short=2;
long_carch=tam_int*11; % Longitud de la estructura ARCHIVADOR: 11 enteros de 32 bit
% Longitud de la configuracin del "Archivador", que est con un desplazamiento igual al tamao
% de la estructura ARCHIVADOR de ddtboard.h, desde final del fichero .mpx.
%    Fecha de captura  (time_t)
%    Nmero de buffers capturados (int)
%    Buffer actual (int)
%    Muestras por canal en un buffer (int)
%    Nmero de canales  (int)
%    Longitud de la configuracin de la tarjeta, que est al principio del fichero .mpx. (int)

fid=fopen(mpx,'r');
fseek(fid,-long_carch,'eof');
carch=fread(fid,inf,'int32');

fecha=carch(1);
desplaz=carch(6);  % Desplazamiento en nmero de short int (enteros de 16 bit)
muestcanbuf=carch(4);  % Muestras por canal y buffer
numcan=carch(5);  % Nmero de canales
numbuf=carch(2);  % Nmero de buffers
bloqact=carch(3); % Bloque actual (aadido en la version MAPREX 1.1)
bits=carch(7);    % Nmero de bits de resolucin (aadido posterior a la versin MAPREX 1.1 inicial)
% Arreglo del aadido a la versin MAPREX 1.1 inicial
if bits~=16 && bits~=24
    bits=12;
end
nummuest=muestcanbuf*numbuf;  % Nmero de muestras total por canal

if nargin==1
	fseek(fid,tam_short*desplaz,'bof');
	datos=fread(fid,[numcan nummuest],'uint16');
	inicio=0;
else
	fseek(fid,tam_short*desplaz+inicio*numcan*tam_short,'bof');
	datos=fread(fid,[numcan longitud],'uint16');
	nummuest=longitud;
end

fseek(fid,0,'bof');
cad=fread(fid,11,'uchar');
cad=cad(1:end-1);
cad=sprintf('%c',cad);
if(strcmp(cad,'MAPREX 1.0') || strcmp(cad,'MAPREX 1.1'))
	numcan2=fread(fid,1,'int32');
	nombres=[];
	ganancias=[];
	canales=[];
	volt_max=[];
	volt_min=[];
	valor_max=[];
	valor_min=[];
	for k=1:numcan
		icanal=fread(fid,3,'int32');
		canales=[canales icanal(1)];
		ganancias=[ganancias icanal(2)];
		long_cad=icanal(3);
		cad=fread(fid,long_cad,'uchar');
		cad=cad(1:end-1);
		cad=sprintf('%c',cad);
		nombres{k}=cad;
		conv=fread(fid,4,'double');
		volt_max=[volt_max conv(1)];
		volt_min=[volt_min conv(2)];
		valor_max=[valor_max conv(3)];
		valor_min=[valor_min conv(4)];
		long_cad=fread(fid,1,'int32');
		cad=fread(fid,long_cad,'uchar');
		cad=cad(1:end-1);
		cad=sprintf('%c',cad);
		unidades{k}=cad;
	end
	fm=fread(fid,1,'double');
	res=2^bits;
	for i=1:size(datos,1)
        % VERSION ANTIGUA
        % tarjetas DT9812 (complemento a 2) 
		%datos(i,:)=bitand(datos(i,:),(2^(bits-1)-1)) - bitand(datos(i,:),2^(bits-1));
        %max=valor_max(i);
        %min=valor_min(i);  
		%datos(i,:)=((max-min)/res)*datos(i,:);
		%datos(i,:)=datos(i,:)/ganancias(i);
        % VERSION AACV NO PROBADA
        %   Solo para tarjetas DT9812 (complemento a 2) 
        %   convert to offset binary by inverting the sign bit
        %datos(i,:)=bitxor(datos(i,:),2^(bits-1));
        %   zero upper bits
        %datos(i,:)=bitand(datos(i,:),(2^bits)-1);
        %   Para todas las tarjetas
        datos(i,:)=transf_afin(10,-10,res,0,datos(i,:))/ganancias(i);
        datos(i,:)=transf_afin(valor_max(i),valor_min(i),volt_max(i),volt_min(i),datos(i,:));
	end
	fecha=[datestr(719529+fecha/86400) ' GMT'];
	x.archivo=mpx;
	x.fecha=fecha;
	x.canales=canales;
	x.ganancias=ganancias;
	x.nombres=nombres;
	x.unidades=unidades;
	x.volt_max=volt_max;
	x.volt_min=volt_min;
	x.valor_max=valor_max;
	x.valor_min=valor_min;
	x.fm=fm;
	%x.t=(inicio/fm:1/fm:(nummuest+inicio-1)/fm)';
	x.t=((inicio:(nummuest+inicio-1))/fm)';
	if strcmp(cad,'MAPREX 1.1')
		% recuperacin en orden, usando el bloqueact (aadido en la version MAPREX 1.1)
		bloqact=mod(bloqact,numbuf);
		x.datos=[datos(:,muestcanbuf*(bloqact)+1:end) datos(:,1:muestcanbuf*(bloqact))]';
	else
		x.datos=datos';
	end
elseif(strcmp(cad,'MAPREX 0.8'))
	numcan2=fread(fid,1,'int32');
	nombres=[];
	ganancias=[];
	canales=[];
	for k=1:numcan
		icanal=fread(fid,3,'int32');
		canales=[canales icanal(1)];
		ganancias=[ganancias icanal(2)];
		long_cad=icanal(3);
		cad=fread(fid,long_cad,'uchar');
		cad=cad(1:end-1);
		cad=sprintf('%c',cad);
		nombres{k}=cad;
	end
	fm=fread(fid,1,'double');

	max=10;
	min=-10;
	res=4096;

	datos=((max-min)/res)*datos+min;


	% now=719529  -> 1-ENE-1970 00:00:00
	fecha=[datestr(719529+fecha/86400) ' GMT']; 

	x.archivo=mpx;
	x.fecha=fecha;
	x.canales=canales;
	x.ganancias=ganancias;
	x.nombres=nombres;
	x.fm=fm;
	x.t=(inicio/fm:1/fm:(nummuest+inicio-1)/fm)';
	x.datos=datos';

else
	error('Versin de archivo no es MAPREX 0.8');
end

fclose(fid);


function y=transf_afin(y0,y1,x0,x1,x)

y=(y1-y0)/(x1-x0)*(x-x0)+y0;

