function [Rj,Cj,Rmat,names] = localpartialcorrelation(p,smap,sigma)
%  [Rj,Cj,Rmat,names] = localpartialcorrelation(p,smap,sigma)
%
% INPUTS
% p:     data matrix (R x N)
% smap:  UnioviSOM SOM struct
% sigma: Width factor in local neighborhood
%
% OUTPUTS
% Rj:      n-array of size (R x R x 10000) one local correlation matrix per SOM unit
% Cj:      n-array of size (R x R x 10000) one local covariance  matrix per SOM unit
% Rmat:    Matrix of size (R^2 x 10000) one column per SOM unit
% names:   List with R^2 labels corresponding to each couple of variables
%
% Example of usage:
%       [Rj,Cj,Rmat,names] = localpartialcorrelation(pn,smap,0.8)
%       planes(pos,Rmat,names);

%   Copyright (c) 2007, by 
%   Grupo de Supervisin y Diagnstico de Procesos Industriales
%   Area de Ingeniera de Sistemas y Automtica
%   Universidad de Oviedo
%   Contributed files may contain copyrights of their own.
%   
%   UniOviSOM toolbox is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.
% 
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
% 
%   You should have received a copy of the GNU General Public License
%   along with this program; if not, write to the Free Software
%   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.


wt = smap.w';
n = size(wt,2);
m = size(wt,1);
nd= size(p,2);
if(length(sigma)==1)
   sigma=sigma*ones(1,n);
end


% Preinicializacion de las variables
% Nota: El preinicializar las variables supuso un incremento de la
% velocidad de casi un orden de magnitud. El no hacerlo, suponia la
% ubicacion dinamica de memoria en tiempo de ejecucion por parte de MATLAB
% lo que lo ralentizaba enormemente...

Cj   = zeros(smap.R,smap.R,n);
Rj   = zeros(smap.R,smap.R,n);
Rmat = zeros(n,smap.R*smap.R);


for c=1:n
   mimc = p-repmat(wt(:,c),1,nd);
   dis  = sum(mimc.^2);
   hci  = exp(-dis/(2*sigma(c)^2));
   rhci = repmat(hci,m,1);
   mediapond = sum(p.*rhci,2)/sum(hci);
   mimc = p-repmat(mediapond,1,nd);
   mimc_hci=mimc.*rhci;
   Cj(:,:,c)=mimc_hci*mimc';   % Creo que para el caso de las correlaciones sobra.   /sum(hci);
   
   Cj(:,:,c) = Cj(:,:,c) + eye(m)*0.0001;
    
   S = Cj(:,:,c);
   S1 = inv(S);  
   Rj(:,:,c) = -sqrt(inv(diag(diag(S1))))*S1*sqrt(inv(diag(diag(S1))))+2*eye(smap.R);
   %d=diag(Cj(:,:,c));
   %Rj(:,:,c)=Cj(:,:,c)./sqrt(d*d');
   
   camb=Rj(:,:,c);
   camb=camb(:)';
   Rmat(c,:) = camb;   
   % Rmat=[Rmat;camb];  % Localizacion dinamica de memoria. Resultaba excesivamente lento...
   if ~rem(c,100)
       fprintf('Processing node: %s / %s\n',num2str(c),num2str(n));
   end
end

   for i=1:m
      for j=1:m
         names{(i-1)*m+j}=[ smap.featnames{i} ' ' smap.featnames{j} ];
% Poner los planos de componentes para aprovechar espacio        
%          if i==j
%             Rmat(:,(i-1)*m+j) = wt(i,:)';
%          end        
      end
   end
   
   Rmat = Rmat';
   
   if nargout==0
       figure;planes(smap.pos,Rmat',names,'alt');
   end
