function d_ij = matdiff(Xi,Xj)

% MATDIFF Difference between vectors
%
% d_ij = matdiff(Xi,Xj)
%
% INPUTS:
% Xi,Xj: Data matrices of size (R,NXi) and (R,NXj) composed by column 
%        vectors of size (R,1).
%
% d_ij:  Matrix (R,NXi*NXj) with difference vectors 
%
% DESCRIPTION:
% d_ij, contains a matrix with difference vectors Xi-Xj placed by
% columns such that reshape(d_ij(k,:)) gives a matrix whose element
% (i,j) is the difference between the k-coordinates of Xi and Xj

%   Copyright (c) 2007, by 
%   Grupo de Supervisin y Diagnstico de Procesos Industriales
%   Area de Ingeniera de Sistemas y Automtica
%   Universidad de Oviedo
%   Contributed files may contain copyrights of their own.
%   
%   UniOviSOM toolbox is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.
% 
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
% 
%   You should have received a copy of the GNU General Public License
%   along with this program; if not, write to the Free Software
%   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.


lxi = size(Xi,2);
lxj = size(Xj,2);

[j,i] = meshgrid(1:lxj,1:lxi);

d_ij = Xi(:,i)-Xj(:,j);

