function dist = matdiscv(Xi,Xj,Cj)
% MATDISCV: Mahalanobis distance
%
% dist = matdiscv(Xi,Xj,Cj)
%
% INPUTS:
% Xi: Data matrix (RxQ) 
% Xj: Data matrix (RxJ)
% Cj: Tensor of J matrices (RxRxJ)
%
% OUTPUTS:
% dist = Distance matrix d(Xi,Xj) ->  dim: (QxJ)
%
% DESCRIPTION
%   Obtains mahalanobis distance from points (columns) of a data matrix Xi 
%   to points (columns) of data matrix Xj 
%
%      d_ij = (Xi-Xj)'Cj(Xi-Xj)

%   Copyright (c) 2007, by 
%   Grupo de Supervisin y Diagnstico de Procesos Industriales
%   Area de Ingeniera de Sistemas y Automtica
%   Universidad de Oviedo
%   Contributed files may contain copyrights of their own.
%   
%   UniOviSOM toolbox is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.
% 
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
% 
%   You should have received a copy of the GNU General Public License
%   along with this program; if not, write to the Free Software
%   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

Ni = size(Xi,2);
Nj = size(Xj,2);
R  = size(Xi,1);



	[j,i]=meshgrid(1:Nj,1:Ni); 
	j = j(:)';
	i = i(:)'; 
	Xij   = Xi(:,i)-Xj(:,j);
	CjXij = zeros(R,Ni*Nj);
	for j = 1:Nj
   	k = j*Ni-Ni+1:j*Ni;
   	CjXij(:,k) = inv(Cj(:,:,j))*Xij(:,k);
	end
	dist = reshape(sum(Xij.*CjXij),Ni,Nj);

   


