function d_ij = matdist(Xi,Xj)

% MATDIST Distance matrix between sets of vectors
%
% d_ij = matdiff(Xi,Xj)
%
% INPUTS:
% Xi,Xj: Data matrices of size (R,NXi) and (R,NXj) composed by column 
%        vectors of size (R,1).
%
% d_ij:  Matrix (NXi,NXj) with the euclidean distances between the 
%        columns of Xi and the columns of Xj


%   Copyright (c) 2007, by 
%   Grupo de Supervisin y Diagnstico de Procesos Industriales
%   Area de Ingeniera de Sistemas y Automtica
%   Universidad de Oviedo
%   Contributed files may contain copyrights of their own.
%   
%   UniOviSOM toolbox is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.
% 
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
% 
%   You should have received a copy of the GNU General Public License
%   along with this program; if not, write to the Free Software
%   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.


li = size(Xi,2);
lj = size(Xj,2);


if li*lj>10000000
   % disp('PRECAUCIN: Demasiado consumo de memoria. Puede colgarse el MATLAB. Saliendo...');
   d_ij = matdist1(Xi,Xj);      % 2005-11-23: Calculo alternativo desglosando la operacion en bloques
   return;
end



xi   = sum(Xi.^2,1);
xj   = sum(Xj.^2,1);


% Old code, with ones
% d_ij = xi'*ones(1,lj) + ones(li,1)*xj - 2*Xi'*Xj;

% Repmat is slightly better than ones as no multiplications and sums are done
d_ij = repmat(xi',[1 lj]) + repmat(xj,[li 1]) - 2*Xi'*Xj;