function [pr,eigenvalues] = mds(dg,dim)
% [pr,eigenvalues] = mds(dg,dim)
%
% MDS: Computes the Multidimensional Scaling Projection using and eigenvalue approach
%
% INPUTS
% dg:  distance or disparity matrix
% dim: output dimension
%
% OUTPUTS
% pr:          projected points in the output space
% eigenvalues: eigenvalues of the tau matrix
%
% Description: 
% This method uses the eigenvalue approach to do MDS. It obtains the MDS
% projection without iterations. A 'centering matrix' is used to convert
% a distance problem into an inner product problem (tau operator). The trick
% has been borrowed from [Tenenbaum00]

%   Copyright (c) 2007, by 
%   Grupo de Supervisin y Diagnstico de Procesos Industriales
%   Area de Ingeniera de Sistemas y Automtica
%   Universidad de Oviedo
%   Contributed files may contain copyrights of their own.
%   
%   UniOviSOM toolbox is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.
% 
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
% 
%   You should have received a copy of the GNU General Public License
%   along with this program; if not, write to the Free Software
%   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.


[dummy,N] = size(dg);

if nargin==1
    dim = 2;
end

% dg = matdist(p,p);

H = eye(N)-1/N;                         % Compute centering matrix
tauD = -H*dg*H/2;                       % Apply operator tau(Dg)
[v,d]=eig(tauD);                        % Reduce dimensionality using typical PCA 
pr = sqrt(d(1:dim,1:dim))*v(:,1:dim)';  % 

eigenvalues = diag(d);