function [mloc_best,LogData] = mloc_busca_valida(mloc,yt,ut,pt,yv,uv,pv,ny,nu,bias,sigma)
% MLOC_BUSCA_VALIDA Entrena mltiples modelos con validacin y selecciona el mejor
%
%        [mloc_best,LogData] = mloc_busca_valida(mloc,yt,ut,pt,yv,uv,pv,ny,nu,bias,sigma)
%
%   mloc: SOM con modelos locales
%     yt: Salidas (conjunto de entrenamiento)
%     ut: Entradas (conjunto de entrenamiento)
%     pt: Selectores de dinmica (conjunto de entrenamiento)
%     yv: Salidas (conjunto de validacin)
%     uv: Entradas (conjunto de validacin) 
%     pt: Selectores de dinmica (conjunto de validacin)
%     ny: vector con los ordenes AR para iterar
%     nu: vector con los ordenes X  para iterar
%   bias: 0 sin bas, 1 con bias
%  sigma: vector con amplitudes del campo receptivo para iterar
%
%  Descripcin:
%     Entrena mltiples SOM con modelos locales (mloc) empleando modelos ARX para todas las combinaciones posibles 
%     entre rdenes ny, nu, y amplitudes del campo receptivo, sigma.
%
%     Cada mloc se simula ante entradas de validacin y compara las salidas obtenidas con las de validacin,
%     devolviendo el SOM con modelos locales que presenta menor AIC



%   Copyright (c) 2007, by 
%   Grupo de Supervisin y Diagnstico de Procesos Industriales
%   Area de Ingeniera de Sistemas y Automtica
%   Universidad de Oviedo
%   Contributed files may contain copyrights of their own.
%   
%   UniOviSOM toolbox is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.
% 
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
% 
%   You should have received a copy of the GNU General Public License
%   along with this program; if not, write to the Free Software
%   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.


warning off;
rmsemin = inf;
AICmin  = inf;


iteracion = 0;
for i1 = ny
    for i2 = nu
        for i3 = sigma
            iteracion = iteracion + 1;
            mloc = mloc_loc(yt,[1:i1],ut,[0:i2],pt,mloc,bias,i3);

            [rmse_t,aux_t,rmselin_t,aux_t,AIC_t] = mloc_compara(yt,ut,pt,mloc);
            [rmse_v,aux_v,rmselin_v,aux_v,AIC_v] = mloc_compara(yv,uv,pv,mloc);
            
            
            AIC      = max([AIC_v,AIC_t]);
            rmse     = max([rmse_v,rmse_t]);
            rmselin  = max([rmselin_v,rmselin_t]);
            
            LogData(iteracion,:) = [i1,i2,i3,rmse,rmselin,AIC];

            % if rmse < rmsemin
            if AIC < AICmin
                AICmin = AIC;
                rmsemin=max([rmse_v,rmse_t]);
                mloc_best = mloc;
                iteracion_best = iteracion;
                fprintf('ny: %d \t nu:%d \t sig=%1.2f \t rmse = %f \t (rmse/rmselin = %f) \t AIC = %f *** \n',i1,i2,i3,rmsemin,rmsemin/rmselin, AIC);
            else    
                fprintf('ny: %d \t nu:%d \t sig=%1.2f \t rmse = %f \t (rmse/rmselin = %f) \t AIC = %f\n',i1,i2,i3,rmse_v,rmse_v/rmselin, AIC);
            end
        end
    end
end
warning on;



mloc_info(mloc_best);


