function [num,den,W,rmse]=mloc_planos(mloc,u,y,p)
% MLOC_PLANOS Dibuja los planos de coeficientes, variables selectoras y RMSE
%
% [num,den,W,rmse]=mloc_planos(mloc)
%
% INPUTS
%   mloc: Objeto mloc
%
% OUTPUTS
%    num: Planos de coeficientes del numerador
%    den: planos de coeficientes del denominador
%      W: Planos con las variables selectoras de la dinmica
%   rmse: Plano con los errores RMSE de cada modelo

%   Copyright (c) 2007, by 
%   Grupo de Supervisin y Diagnstico de Procesos Industriales
%   Area de Ingeniera de Sistemas y Automtica
%   Universidad de Oviedo
%   Contributed files may contain copyrights of their own.
%   
%   UniOviSOM toolbox is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.
% 
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
% 
%   You should have received a copy of the GNU General Public License
%   along with this program; if not, write to the Free Software
%   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.


ny = mloc.ny;
nu = mloc.nu;
nq = mloc.nq;
np = mloc.np;

j = 0;
for k = ny
    j = j + 1;
    etiq_loc{j} = sprintf('a(%d)',k);
    for i = 1:mloc.som.S
        T(j,i) = mloc.Mcell{i}(j);
    end
end

for k = nu
    j = j + 1;
    etiq_loc{j} = sprintf('b(%d)',k);
    for i = 1:mloc.som.S
        T(j,i) = mloc.Mcell{i}(j);
    end
end

if mloc.usar_bias
    j = j + 1;
    etiq_loc{j} = sprintf('bias');
    for i = 1:mloc.som.S
        T(j,i) = mloc.Mcell{i}(j);
    end
end



j = 0;

for k = mloc.nq
    j = j + 1;
    if k
        etiq_som{j} = sprintf('y(k-%d)',k);
    else
        etiq_som{j} = sprintf('y(k)');
    end
    Wn(j,:) = mloc.som.w(:,k)';
end


for k = mloc.np
    for dim_p = 1:[size(mloc.som.w,2)-j]/length(mloc.np)
        j = j + 1;
        if k
            etiq_som{j} = sprintf('p(k-%d)',k);
        else
            etiq_som{j} = sprintf('p(k)');
        end
        Wn(j,:) = mloc.som.w(:,j)';
    end
end

% DESNORMALIZAMOS
W = norpca(Wn,mloc.A,mloc.b,1);

% DEVUELVE EL PLANO CON EL ERROR RMSE
rmse = mloc.rmse;



if nargout==0
    h1 = figure;
    h2 = figure;


    figure(h1);
    
    if length(mloc.nq)>1
        aux = norpca(mloc.som.w',mloc.A,mloc.b,1);
        dw = -diff(aux(1:length(mloc.nq),:));
        for k = 1:size(dw,1)
            etiq_dsom{k} = sprintf('\\Delta %s',etiq_som{k});
        end
        h = planes(mloc.som.pos,[T;W;dw;mloc.rmse;mloc.rango],{etiq_loc{:},etiq_som{:},etiq_dsom{:},'RMSE','Rank'});
        set(gcf,'name','Coefficient Maps','Position',[113 39 1049 684]);
    else
        h = planes(mloc.som.pos,[T;W;mloc.rmse;mloc.rango],{etiq_loc{:},etiq_som{:},'RMSE','Rank'});
        set(gcf,'name','Coefficient Maps','Position',[113 39 1049 684]);
    end

    
    
    
    
    
    figure(h2);
    set(gcf,'name','Frequency Response Maps','Position',[43 -7 1196 730]);
    den = [ones(1,mloc.som.S); -T(1:length(ny),:)];
    num = T(length(ny)+1:length(ny)+length(nu),:);
    if size(num,1)==0       % si es un modelo AR(n)
        num = ones(1,400);
    end
    w = [0:0.05:0.05*(16-mloc.som.R-1)]*2*pi;
    w = w(1:end-1);
    Gjw = multibode(num,den,w);
%     maxg = ceil(max(20*log10(abs(Gjw(:))))/20)*20;
%     ming = floor(min(20*log10(abs(Gjw(:))))/20)*20;
    aux = 20*log10(abs(Gjw(:))); media = mean(20*log10(abs(Gjw(:)))); desviacion = std(20*log10(abs(Gjw(:))));
    maxg = ceil ((media+desviacion*1)/20)*20; media, desviacion,
    ming = floor((media-desviacion*1)/20)*20;
    for k = 1:length(w),
        etiqfrec{k}=sprintf('f/f_s = %1.2g (p.u.)',w(k)/2/pi);
    end
    if length(mloc.nq)>1
        aux = norpca(mloc.som.w',mloc.A,mloc.b,1);
        dw = -diff(aux(1:length(mloc.nq),:));
        for k = 1:size(dw,1)
            etiq_dsom{k} = sprintf('\\Delta %s',etiq_som{k});
        end
        planes(mloc.som.pos,[20*log10(abs(Gjw));norpca(mloc.som.w',mloc.A,mloc.b,1);dw],{etiqfrec{:} etiq_som{:} etiq_dsom{:}},'cont',[ones(length(w),1)*[ming maxg];minimaxi(norpca(mloc.som.w',mloc.A,mloc.b,1));minimaxi(dw)]);
    else
        planes(mloc.som.pos,[20*log10(abs(Gjw));norpca(mloc.som.w',mloc.A,mloc.b,1)],{etiqfrec{:} etiq_som{:}},'cont',[ones(length(w),1)*[ming maxg];minimaxi(norpca(mloc.som.w',mloc.A,mloc.b,1))]);
    end
    

    % 2007.02.02: ESTA PARTE NO ES IMPRESCINDIBLE
    % % % % %     [i,j]=ginput;
    % % % % %     pos = round([i j]');
    % % % % %     [qerr,bmu]=min(matdist(mloc.som.pos,pos));
    % % % % %     den = [ones(1,length(bmu)); -T(1:length(ny),bmu)];
    % % % % %     num = T(length(ny)+1:length(ny)+length(nu),bmu);
    % % % % %     th = linspace(0,pi*0.75,500);
    % % % % %     plotp(pos,'.','all');
    % % % % %     for k = 1:length(h)
    % % % % %         axes(h(k))
    % % % % %         for m = 1:size(pos,2)
    % % % % %             text(pos(1,m),pos(2,m),num2str(m),'horiz','cent');
    % % % % %         end
    % % % % %     end
    % % % % %     figure(h2);
    % % % % %     semilogx(th,20*log10(abs(multibode(num,den,th))));
    % % % % %     xlabel('\theta');
    % % % % %     grid on;
    % % % % %     for k = 1:length(bmu)
    % % % % %         etiq{k} = num2str(k);
    % % % % %     end
    % % % % %     legend(etiq{:});

    if nargin==4
        h3 = figure;
        % Se crean vectores "augmented"
        idx = max([ny nu np nq])+1:length(y);

        % Variable "augmented" de salida del proceso
        phiy = [];
        for j = 1:length(ny)
            phiy = [phiy;y(:,idx-ny(j))];
        end

        % Variable "augmented" de entrada al proceso
        phiu = [];
        for j = 1:length(nu)
            phiu = [phiu;u(:,idx-nu(j))];
        end

        % VARIABLES SELECTORAS DE DINMICA
        % Al considerar retardos incluimos la propia dinamica de la variable como
        % elemento de seleccion en la dinamica del proceso. Como caso particular,
        % haciendo p = y, tenemos el caso de procesos no lineales descrito por [Cho
        % y Principe]


        % Inicializacin
        phip = [];

        % Parte endgena
        for j = 1:length(nq)
            phip = [phip;y(:,idx-nq(j))];
        end

        % Parte exgena
        for j = 1:length(np)
            phip = [phip;p(:,idx-np(j))];
        end

        pp = norpca(phip,mloc.A,mloc.b);
        figure(h3);
        pr = fproj(pp,mloc.som);
        [bmu] = find(sqrt(matdist(pr,pos(:,end)))<mloc.sigma);
        subplot(211); 
        plot(idx,phiy(1,:)); 
        hold on; 
        for k = 1:length(ny)
            plot(idx(bmu)-ny(k),phiy(k,bmu-ny(1))','r.'); 
        end
        % hold off;
        % subplot(222); 
        plot(idx,phiu(1,:),'k'); hold on; 
        for k = 1:length(nu)
            plot(idx(bmu)-nu(k),phiu(k,bmu-nu(1))','m.'); 
        end
        
        subplot(223);
        plotsom(mloc.som);
        hold on;
        plotp(pp(:,bmu),'kx',10);
        hold off;
        

        subplot(224);
        plotsom(mloc.som,'outp');
        hold on;
        plotp(pr(:,bmu),'kx',10);
        hold off;

        
    end

    % pause;
else
    den = [ones(1,mloc.som.S); -T(1:length(ny),:)];
    num = T(length(ny)+1:length(ny)+length(nu),:);
end




