function [Pol,Str,planes]=modelmaps(p,C,som,vars)

% MODELMAPS Gets polynomial models from data interactively
%
% CALLS
%
%          [Pol,Str,planes] = modelmaps(p,C,som,vars)
%
% p: data matrix (RxQ)
%    C: Covariance value (scalar)
%  som: SOM structure
% vars: indices of two variables to be analyzed
%
%    Pol: Cell array containing vectors of polynomial coefficients
%         for each polynomial model P(x)
%    Str: Cell array containing strings with the polynomial model (meant for
%         titles) 
% planes: Residual planes corresponding to evaluation of res = y-P(x)
%
% Description
%   MODELMAPS allows to obtain polynomial models between two variables in
%   an easy way by clicking points in a scatter plot. The validity of the
%   obtained models can be assessed later over the SOM model by evaluating
%   the residuals y-P(x) for variables x and y of the SOM codebooks. This
%   is automatically done in the variable planes.

%   Copyright (c) 2007, by 
%   Grupo de Supervisin y Diagnstico de Procesos Industriales
%   Area de Ingeniera de Sistemas y Automtica
%   Universidad de Oviedo
%   Contributed files may contain copyrights of their own.
%   
%   UniOviSOM toolbox is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.
% 
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
% 
%   You should have received a copy of the GNU General Public License
%   along with this program; if not, write to the Free Software
%   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.



xstr = som.featnames{vars(1)};
ystr = som.featnames{vars(2)};

% Draw a pdfscatter visualization
pdfscatter(p(vars,:),C);
xlabel(xstr);
ylabel(ystr);

i = 0;
while 1,
    i = i+1;
    % Get a Polynomial Model
    pts = ginput';
    N   = length(pts);
    if N == 0
        return;
    end
    t   = linspace(min(som.w(:,vars(1))),max(som.w(:,vars(1))),100);
    P   = polyfit(pts(1,:),pts(2,:),N-1);
    hold on; 
    plot(t,polyval(P,t),'k');
    hold off;
    
    str = ['<' xstr ',' ystr '>: P(x)='];
    for k = 1:N-1
        str = [str num2str(P(k),'%1.3f') 'x^' num2str(N-k)];
        if P(k+1)>=0
            str = [str '+'];
        end
    end
    str = [str num2str(P(N),'%1.3f')];
    
    Pol{i}=P;
    Str{i}=str;
    planes(i,:) = som.w(:,vars(2))'-polyval(P,som.w(:,vars(1)))';
end


