% def neuralgas(p,S,epochs,Nc):
% 	"""
% 	BATCH NEURALGAS ALGORITHM
% 
% 	w = neuralgas(p,S,epochs,Nc)
% 
% 	Trains a NeuralGas using the batch algorithm.
% 
% 	INPUTS
% 	p:    	2D array of shape (n,N) containing N vectors (columns) of dimension n
% 	S: 	Number of Gas units
% 	epochs: Number of iterations on which the whole data are used
% 	Nc: 	Final neighborhood. Large values lead to regularized (smooth, 
% 		with good topology preserving) approximations. 
% 		Small values lead to better approximation but less regularized 
% 		(noisy worse topology preserving) 
% 
% 	OUTPUTS
% 	w:		2D array of shape (n,S) containing the S codebook vectors 
% 			of the SOM
% 	"""
% 	R,Q  = p.shape
% 	w    = randn(R,S)
% 	Nc   = logspace(log10(S),log10(Nc),epochs)
% 	for i in range(epochs):
% 		d = matdist(w,p)
% 		q = d.min(0)
% 		c = d.argsort(0)
% 		rnk = zeros((S,Q))
% 		u = arange(S)[:,newaxis]; 
% 		uu = arange(Q)[newaxis,:].repeat(S,0); 
% 		rnk[c,uu] = u
% 		hci  = exp(-rnk.T**2/(2*Nc[i]))
% 		hcis = sum(hci,0)
% 		w = (dot(hci.T,p.T)/r_[[hcis]*p.shape[0]].T).T
% 		print "Epoch: %d \t Neigh %f \t MSE = %f"%(i,Nc[i],mean(q))
% 	return w
% 
%     
%     

function w = neuralgas(p,S,epochs,Nc)

[R,Q] = size(p);
w = randn(R,S);
disp('Iterando...');
Nc = logspace(log10(S/2),log10(Nc),epochs);
for i = 1:epochs
    [s,idx] = sort(matdist(w,p));
    rnk = zeros(S,Q);
    for j = 1:Q
        rnk(idx(:,j),j) = (0:S-1)';
    end
    hci = exp(-rnk/Nc(i));
    w = (p*hci')./(ones(R,Q)*hci');
    fprintf('Epoca %d / %d\n',epochs,i);
end
fprintf('...hecho\n');

    
