function [y,norm_par]=normalize_data(ntype,x,npar)
%
%   [y,norm_par]=normalize_data(ntype,x)
%       ntype: 'mnmx' or 'std'
%   y=normalize_data('apply',x,norm_par)
%   x=normalize_data('reverse',y,norm_par)
%
%   WARNING: Constant rows in x return as NaNs in y
%

if nargin~=2 && nargin~=3
    error('Wrong number of input parameters');
elseif ~ischar(ntype)
    error('First input parameter must be a string');
end

switch ntype
    case {'mnmx'}
        [y,norm_par.minx,norm_par.maxx]=uspremnmx(x);
        norm_par.type=ntype;
    case {'std'}
        [y,norm_par.meanx,norm_par.stdx]=usprestd(x);
        norm_par.type=ntype;
    case {'apply'}
        if nargin~=3
            error('Three input parameters expected');
        elseif strcmp(npar.type,'mnmx')
            y=ustramnmx(x,npar.minx,npar.maxx);
        elseif strcmp(npar.type,'std')
            y=ustrastd(x,npar.meanx,npar.stdx);
        else
            error('Unknown normalization type: %s',ntype);
        end
    case {'reverse'}
        if nargin~=3
            error('Three input parameters expected');
        elseif strcmp(npar.type,'mnmx')
            y=uspostmnmx(x,npar.minx,npar.maxx);
        elseif strcmp(npar.type,'std')
            y=uspoststd(x,npar.meanx,npar.stdx);
        else
            error('Unknown normalization type: %s',ntype);
        end
    otherwise
        error('Unknown normalization type or operation: %s',ntype);
end


function [pn,minp,maxp]=uspremnmx(p)
%
%   [pn,minp,maxp]=uspremnmx(p)
%

maxpn=1;
minpn=-1;
maxp=max(p,[],2);
minp=min(p,[],2);
M=size(p,2);
pn=(maxpn-minpn)*(p-repmat(minp,1,M))./repmat(maxp-minp,1,M)+minpn;


function pn=ustramnmx(p,minp,maxp)
%
%   pn=ustramnmx(p,minp,maxp)
%

maxpn=1;
minpn=-1;
M=size(p,2);
pn=(maxpn-minpn)*(p-repmat(minp,1,M))./repmat(maxp-minp,1,M)+minpn;


function p=uspostmnmx(pn,minp,maxp)
%
%   p=uspostmnmx(pn,minp,maxp)
%

maxpn=1;
minpn=-1;
M=size(pn,2);
p=repmat(maxp-minp,1,M).*(pn-minpn)/(maxpn-minpn)+repmat(minp,1,M);


function [pn,meanp,stdp]=usprestd(p)
%
%   [pn,meanp,stdp]=usprestd(p)
%

meanp=mean(p,2);
stdp=std(p,0,2);
M=size(p,2);
pn=(p-repmat(meanp,1,M))./repmat(stdp,1,M);


function pn=ustrastd(p,meanp,stdp)
%
%   pn=ustrastd(p,meanp,stdp)
%

M=size(p,2);
pn=(p-repmat(meanp,1,M))./repmat(stdp,1,M);


function p=uspoststd(pn,meanp,stdp)
%
%   p=uspoststd(pn,meanp,stdp)
%

M=size(pn,2);
p=pn.*repmat(stdp,1,M)+repmat(meanp,1,M);


