function h = pdfscatter(p,C,vars,etiq)

% PDFSCATTER Scatter plot with superimposed pdf plot
%
% CALLS
%
%    pdfscatter(p,C,vars,etiq)
%
%
% INPUTS
%    p: data matrix (RxQ)
%    C: width factor (sigma value)
% etiq: cell array with labels corresponding to the variables of p
% vars: index vector with the variables (rows) of p to be displayed
%
% Description
%    PDFSCATTER obtains a scatter plot with a superimposed probability
%    density plot. This allows to account for cases in which multiple
%    instances of points appear in p with the same (or very similar) coordinates. 
%    The density plot gives a visual cue of the real trends in the
%    distribution of the data points of p

%   Copyright (c) 2007, by 
%   Grupo de Supervisin y Diagnstico de Procesos Industriales
%   Area de Ingeniera de Sistemas y Automtica
%   Universidad de Oviedo
%   Contributed files may contain copyrights of their own.
%   
%   UniOviSOM toolbox is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.
% 
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
% 
%   You should have received a copy of the GNU General Public License
%   along with this program; if not, write to the Free Software
%   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.


clf;


if nargin==2
    vars = [1 2];
    etiq{1} = 'var 1';
    etiq{2} = 'var 2';
end

if nargin==3
    etiq={'var 1','var 2'};
end

p    = p(vars,:);
etiq = etiq(vars);

if length(etiq)~=size(p,1)
    length(etiq),
    size(p,1),
    disp('ERROR: Number of labels does not match the number of rows of p()');
    return
end


[pn,pn_npar] = normalize_data('mnmx',p)

tn = linspace(-1.2,1.2,40);

% Parece que no sirve para nada.
% tn_npar.type = pn_npar.type;
% tn_npar.minx = pn_npar.minx(1);
% tn_npar.maxx = pn_npar.maxx(1);
% t = normalize_data('reverse',tn,tn_npar);

un = rectop(tn,tn,'idx');
u = normalize_data('reverse',un,pn_npar);

phi = mvg(un,pn,C);
phis= mean(phi,2)';

h = planes(u,phis,{'PDFscatter plot'},'cont');
hold on;
plotp(p);
hold off;

%xlabel(etiq(1));
%ylabel(etiq(2));
xlabel(etiq{1});
ylabel(etiq{2});


