function plotcolor(x,y,z,minz,maxz,linewidth)
% PLOTCOLOR linear plot of x versus y using color coding for z 
%
% CALLS
% plotcolor(x,y,z,minz,maxz)
%
% INPUTS
%   x: horizontal variabl [1xN]
%   y: vertical variable
%   z: color variable
%   minz: bottom value of color scale (optional)
%   maxz: top    value of color scale (optional)
%   linewidth: width of the plot line
%
% EXAMPLES
%   figure(1);
%   clf;
%   x = linspace(0,10,1000); 
%   y = sin(x); 
%   z = cos(3*x); 
%   plotcolor(x,y,z,-2,2);
%   colorbar;


%   Copyright (c) 2013, by 
%   Grupo de Supervisin y Diagnstico de Procesos Industriales
%   Area de Ingeniera de Sistemas y Automtica
%   Universidad de Oviedo
%   Contributed files may contain copyrights of their own.
%   
%   UniOviSOM toolbox is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.
% 
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
% 
%   You should have received a copy of the GNU General Public License
%   along with this program; if not, write to the Free Software
%   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

% data length
N = length(x);

% default limits
if nargin==3
    minz = min(z);
    maxz = max(z);
    linewidth = 1;
end

% Default linewidth
if nargin==5
    linewidth=1;
end

a = colormap;

% z values mapped as an integer index of color matrix a
% values are constrained to minz and maxz (forcing color saturation if z is
% out of the bounds minz,maxz)
zidx = round(map(constrain(z,minz,maxz),minz,maxz,1,64));


for i=2:N
    x1 = x(i-1);
    y1 = y(i-1);
    x2 = x(i);
    y2 = y(i);
    h = line([x1,x2],[y1,y2]);
    set(h,'color',mean(a(zidx(i-1:i),:)));
    set(h,'linewidth',linewidth);
end

set(gca,'clim',[minz,maxz]);



