function plotcov(p,C)
% PLOTCOV Plots covariance ellipsoids
%
%         plotcov(p,C)       
%
% Inputs 
% p: Center points of the covariance matrix by columns (RxQ)
% C: Covariance matrix specification can be either:
%    a) a scalar with a single variance for all the center (hyperspheres)
%    b) a vector (1xQ), with the values of the variances for each center (hyperspheres)
%    c) a n-array (RxRxQ) with covariance matrices Cj,  j=1:Q (hyperellipsoids)
%
% See also QUADPLOT, INITCOV 

%   Copyright (c) 2007, by 
%   Grupo de Supervisin y Diagnstico de Procesos Industriales
%   Area de Ingeniera de Sistemas y Automtica
%   Universidad de Oviedo
%   Contributed files may contain copyrights of their own.
%   
%   UniOviSOM toolbox is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.
% 
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
% 
%   You should have received a copy of the GNU General Public License
%   along with this program; if not, write to the Free Software
%   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.


R  = size(p,1);
Nj = size(p,2);

if length(C)==1
    for k = 1:Nj
        Cj(:,:,k) = C*eye(R);
    end
elseif (size(C,3) == 1)
    for k = 1:Nj
        Cj(:,:,k) = C(1,k)*eye(R);
    end
else
    Cj = C;
end

plotp(p);
hold on;
for k = 1:Nj
    quadplot(Cj(:,:,k),p(:,k));
end
hold off;
axis equal;


    
       
