function plotsom(varargin)
% PLOTSOM Plots the som lattice in the input and output space
%
% CALLS
%   plotsom(smap)
%   plotsom(smap,type);
%   plotsom(p,smap);
%   plotsom(p,smap,type);
%
% INPUTS
%      p: Input data matrix (R x Q) where each column is a point
%   smap: SOM object
%   type: string specifying the type of plot. 
%         Can be either of these:
%            'input': refers to the input space
%           'output': refers to the output space
%    'Visualization': refers to the output space
%             'both': draws input and output space
%
% See also PLOTGRID, PLANES, PLANES3D


%   Copyright (c) 2007, by 
%   Grupo de Supervisin y Diagnstico de Procesos Industriales
%   Area de Ingeniera de Sistemas y Automtica
%   Universidad de Oviedo
%   Contributed files may contain copyrights of their own.
%   
%   UniOviSOM toolbox is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.
% 
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
% 
%   You should have received a copy of the GNU General Public License
%   along with this program; if not, write to the Free Software
%   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.


nargin = length(varargin);
if nargin == 1
    smap = varargin{1};
    plotgrid(smap.w',smap.dis);    
elseif nargin == 2
    if isstruct(varargin{2})
        p = varargin{1};
        smap = varargin{2};
        plotp(p); hold on; plotgrid(smap.w',smap.dis); hold off;
        axis tight;
    else
        smap = varargin{1};
        space = varargin{2};
        if strncmp(space,'input',1)
            plotgrid(smap.w',smap.dis);
            axis tight;
            title('Input Space');
        elseif strncmp(space,'output',1) || strncmp(space,'visualization',1)
            plotgrid(smap.pos,smap.dis);
            axis tight;
            title('Visualization Space');
        elseif strncmp(space,'both',1)
            subplot(121);
            plotgrid(smap.w',smap.dis);
            title('Input Space');
            axis tight;
            subplot(122);
            plotgrid(smap.pos,smap.dis);
            axis tight;
            title('Visualization Space');
        end
    end
elseif nargin==3
    p = varargin{1};
    smap = varargin{2};
    space = varargin{3};    % dummy parameter (not used)
    subplot(121);
    plotgrid(smap.w',smap.dis); hold on;
    plotp(p,'kx',10); hold off;
    axis tight;
    subplot(122);
    pr = fproj(p,smap);
    title('Input Space');
    plotgrid(smap.pos,smap.dis); hold on;
    plotp(pr,'kx',10); hold off;
    axis tight;
    title('Visualization Space');
    
end


