function quadplot(P,x,color,N)
% QUADPLOT Plots 2D covariance ellipsoid
% quadplot(P,x)
%
% INPUTS
%     P: Covariance matrix (RxR)
%     x: Center point (Rx1)
% color: color string ('r','g','b', etc.)
%     N: number of points to compute in the ellipsoid (scalar)

%   Copyright (c) 2007, by 
%   Grupo de Supervisin y Diagnstico de Procesos Industriales
%   Area de Ingeniera de Sistemas y Automtica
%   Universidad de Oviedo
%   Contributed files may contain copyrights of their own.
%   
%   UniOviSOM toolbox is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.
% 
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
% 
%   You should have received a copy of the GNU General Public License
%   along with this program; if not, write to the Free Software
%   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.



if     nargin == 2
color = 'r';
N     = 20;
elseif nargin == 3
N     = 20;
elseif nargin ~=4
error('Numero de argumentos incorrecto');
end;


% For covariance matrices we can use SVD to find a 
% matrix root T such that
%   a) P = T*T'
%   b) Column vectors of T are mutually orthogonal
% Matrix T can be seen as a linear transformation whose
% associated norm is P. Hence, it transforms a circle into the
% ellipsoid associated to P.
[U,S,V] = svd(P);
T       = U*sqrt(S);

rho = linspace(0,2*pi,N);
u   = [cos(rho); sin(rho)];
y   = T*u;

plot(y(1,:)+x(1),y(2,:)+x(2),color);
% axis([x(1)-4 x(1)+4 x(2)-4 x(2)+4]);
grid on;

