function pos=rectop(varargin);
% RECTOP - Stores cartesian product of indices on an N-D grid
%
% pos = rectop(Ni,Nj,Nk,...)
%
% Generates a n-d rectangular grid with Ni x Nj x ... as a matrix where 
% each column is an n-d vector corresponding to each point in the rectangular 
% grid.
%
% pos = rectop(i1,i2,...,'idx')
% 
% Generates a n-d rectangular grid with the same structure described above
% resulting from the cartesian product of indexes i1, i2, ...

%   Copyright (c) 2007, by 
%   Grupo de Supervisin y Diagnstico de Procesos Industriales
%   Area de Ingeniera de Sistemas y Automtica
%   Universidad de Oviedo
%   Contributed files may contain copyrights of their own.
%   
%   UniOviSOM toolbox is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.
% 
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
% 
%   You should have received a copy of the GNU General Public License
%   along with this program; if not, write to the Free Software
%   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.


% Handle particular case (1-dim SOM grid):
% NSGRID does not work fine when called with 1 parameter
if length(varargin)==1
    pos = 1:varargin{1};
    return
elseif (length(varargin)==2 && strcmp(varargin{2},'idx'))
    pos = varargin{1}(:)';
    return
end


% Most typical case:
nargin = length(varargin);
if varargin{end} == 'idx'
    nargin = nargin-1;
    for k = 1:nargin
        idx{k} = varargin{k};
    end
else
    for k = 1:nargin
        idx{k} = 0:varargin{k}-1;
    end
end

out = cell(1,nargin);
[out{:}] = ndgrid(idx{:});

for k = 1:nargin
    pos(k,:) = out{k}(:)';
end
