function [posi,pos] = rectopi(varargin);
% INTERPOLATED GRID WITH RECTANGULAR TOPOLOGY
%
% posi = rectopi(Ni,Nj,Nk,...,ni,nj,...)
%
% Generates a n-d rectangular grid with ni x nj x ... elements as ranging from
% 0-Ni, 0-Nj, ... respectively and stores it as a matrix where each column is 
% an n-d vector corresponding to each point in the rectangular grid.
%
% [posi,pos] = rectopi(Ni,Nj,Nk,...,ni,nj,...) returns also the non-interpolated
% grid.
%

%   Copyright (c) 2007, by 
%   Grupo de Supervisin y Diagnstico de Procesos Industriales
%   Area de Ingeniera de Sistemas y Automtica
%   Universidad de Oviedo
%   Contributed files may contain copyrights of their own.
%   
%   UniOviSOM toolbox is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.
% 
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
% 
%   You should have received a copy of the GNU General Public License
%   along with this program; if not, write to the Free Software
%   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.



nargin = length(varargin)/2;
for k = 1:nargin
    idx{k}  = 0:varargin{k}-1;
    idxi{k} = linspace(0,varargin{k}-1,varargin{k+nargin});
end

out  = cell(1,nargin);
outi = cell(1,nargin);
[out{:}]  = ndgrid(idx{:});
[outi{:}] = ndgrid(idxi{:});

for k = 1:nargin
    pos(k,:)  = out{k}(:)';
    posi(k,:) = outi{k}(:)';
end
