function [idx,D] = selecciona(p,nombres)
% SELECCIONA Seleccion grafica de un conjunto de puntos
%       [idx,D] = selecciona(p,nombres)
%
% ENTRADAS
%       p: vector de puntos (2xN)
% nombres: cell array con etiquetas (strings) asociadas a cada punto
%
% SALIDAS
%     idx: indices de los elementos rodeados
%       D: numero neto de radianes girados para cada punto
%
% DESCRIPCION
% La funcion permite realizar una seleccion de un conjunto de puntos de
% forma grafica, rodeandolos mediante un contorno.

%   Copyright (c) 2007, by 
%   Grupo de Supervisin y Diagnstico de Procesos Industriales
%   Area de Ingeniera de Sistemas y Automtica
%   Universidad de Oviedo
%   Contributed files may contain copyrights of their own.
%   
%   UniOviSOM toolbox is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.
% 
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
% 
%   You should have received a copy of the GNU General Public License
%   along with this program; if not, write to the Free Software
%   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

hold on;
plotp(p);

if nargin==2
    for k = 1:size(p,2)
        text(p(1,k),p(2,k),[' ',nombres{k}]);
    end
end

k = 0;
q = [];
while 1,
    k=k+1;
    [q(1,k),q(2,k),b] = ginput(1);
    if b==3
        q(:,k) = q(:,1);
    end
    hold on;
    plotp(q,'-');
    hold off;
    if b==3
        break;
    end
end

drawnow;


q = q(1,:) + j*q(2,:);
p = p(1,:) + j*p(2,:);





lq = length(q);
lp = length(p);

D = [];
for k = 1:lp
    pd = q - repmat(p(k),1,lq);
    D(:,k) = sum(diff(unwrap(angle(pd))));
end


idx1 = find(abs(D-2*pi)<0.0001);
idx2 = find(abs(D+2*pi)<0.0001);

idx = union(idx1,idx2);

    

