function [som, res_Vef, res_std] = som_permess(p,som)
% SOM_PERMESS
%   [som, res_Vef, res_std] = som_permess(p,som)
%
% INPUTS
%   p: datos de entrenamiento; matriz con Q vectores columna de R variables; [R x Q]
% som: objeto som
%
% OUTPUTS
%     som: objeto som con los nuevos campos 'Vef' y 'std'
% res_Vef: matriz de residuos normalizados segn el valor eficaz de las variables de proceso; [R x Q]
% res_std: matriz de residuos normalizados segn la desviacin tpica de los residuos; [R x Q]
%
% EJEMPLO (copiar y pegar):
% datos = load('datosmotorlaminacion');                     % cargamos datos de un motor de laminacin
% for k = 1:size(datos.p,1)                                 % diezmamos (tomamos una muestra de cada 100)
%   pd(k,:) = decimate(datos.p(k,:),100);
% end
% pt = pd(:,1:1000);                                        % pt es el conjunto de entrenamiento 
%                                                           % formado por los 1000 primeros datos
% som = inisom(pt,{20,20},datos.nombres);                   % entrenamos un SOM con pt
% som = bsom(pt,som,10,0.5);                                
% som = som_permess(pt,som);                                % incorporamos Vef y std al objeto som
% [pr,res]=fproj(pd,som);                                   % calculamos residuos con todo el
%                                                           % conjunto de datos pd
% figure(1);
% imagesc(inv(diag(som.std))*res,[-1 1]*3); colorbar;       % Residuos normalizados por std
% title('Residuos normalizados por std (\pm 3 \sigma)')
% figure(2);
% imagesc(inv(diag(som.Vef))*res,[-1 1]*0.2); colorbar;     % Residuos normalizados por Vef
% title('Residuos normalizados por Vef (\pm 20 %)')


%   Copyright (c) 2007, by 
%   Grupo de Supervisin y Diagnstico de Procesos Industriales
%   Area de Ingeniera de Sistemas y Automtica
%   Universidad de Oviedo
%   Contributed files may contain copyrights of their own.
%   
%   UniOviSOM toolbox is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.
% 
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
% 
%   You should have received a copy of the GNU General Public License
%   along with this program; if not, write to the Free Software
%   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.


% VALORES EFICACES DE LAS VARIABLES
som.Vef = sqrt(mean(p.^2,2));


% DESVIACION TPICA DE LOS RESIDUOS
[pr,res] = fproj(p,som);
som.std = std(res')';




res_Vef = diag(1./som.Vef)*res;
res_std = diag(1./som.std)*res;




