function [D,Dmax,Dmin]=somdist(som)
% SOMDIST  Distance map for SOM
%
%          [D,Dmax,Dmin]=somdist(som)
%
%            INPUTS:
%                 som: smap type structure (UnioviSOM)
%
%            OUTPUTS:
%                 D:    Mean distance value of 1-neighbours.
%                 Dmax: Max  distance value of 1-neighbours.
%                 Dmin: Min  distance value of 1-neighbours.
%


%   Copyright (c) 2007, by 
%   Grupo de Supervisin y Diagnstico de Procesos Industriales
%   Area de Ingeniera de Sistemas y Automtica
%   Universidad de Oviedo
%   Contributed files may contain copyrights of their own.
%   
%   UniOviSOM toolbox is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.
% 
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
% 
%   You should have received a copy of the GNU General Public License
%   along with this program; if not, write to the Free Software
%   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.


S   = som.S;             
pos = som.pos;
wbp = som.w';
ni  = som.dims{1};
nj  = som.dims{2};
D   = zeros(1,S);


for k=1:S
    x=pos(1,k);
    y=pos(2,k);
    x=[ x (x-1) (x+1) x ];
    y=[ (y-1) y y (y+1) ];
    nofuera=find( x>=0 & x<ni & y>=0 & y<nj );
    x=x(nofuera);
    y=y(nofuera);
    vecin=x+y*ni+1;
    numvecin=length(vecin);
    mdist=wbp(:,vecin);
    mdist=mdist-wbp(:,k)*ones(1,numvecin);
    mdist=sqrt(sum(mdist.*mdist));
    D(k)=sum(mdist)/numvecin;
    Dmax(k)=max(mdist);
    Dmin(k)=min(mdist);
end


if nargout==0
    planes(pos,D);
end
