function smapi = sominterp(smap,newdims)

% SOMINTERP Generation of a new SOM by resampling the original one.
%
%          smapi = sominterp(smap,newdims)
%
%    smap: SOM struct
% newdims: cell array with the new dimensions (topology must be the same intrinsic
%          dimension than original SOM.
%


%   Copyright (c) 2007, by 
%   Grupo de Supervisin y Diagnstico de Procesos Industriales
%   Area de Ingeniera de Sistemas y Automtica
%   Universidad de Oviedo
%   Contributed files may contain copyrights of their own.
%   
%   UniOviSOM toolbox is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.
% 
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
% 
%   You should have received a copy of the GNU General Public License
%   along with this program; if not, write to the Free Software
%   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.


posc  = rectopi(smap.dims{:},7,7),
posi  = rectopi(smap.dims{:},newdims{:});
sigma = 1.5*(posc(1,2)-posc(1,1)),
fwd   = grnntra(smap.w',smap.pos,sigma,1e-5,posc,1);


% Generate the new SOM structure. 
% Copy fields which remain unchanged and redefine new fields
smapi = smap;           % nueva linea
smapi.dims = newdims;
smapi.R    = smap.R;
smapi.S    = size(posi,2);
smapi.pos  = posi;
smapi.w    = grnnsim(posi,fwd)';
smapi.featnames = smap.featnames;

if prod([newdims{:}])<4000
    smapi.dis  = distenlace(rectop(newdims{:}));
else
    disp('Too large net size. No distance matrix was generated.');
end

