function [ud,yd]=tddata(u,y,AR,MA,d);
% TDDATA Construye una "time-delay data matrix"
%        [ud,yd]=tddata(u,y,AR,MA,d);
%
%   u:  Matriz de vectores de entrada u(:,i) de tamao (nu x N)
%   y:  Matriz de vectores de salida  y(:,i) de tamao (ny x N)
%  AR:  Orden de la componente autorregresiva
%  MA:  Orden de la componente de media movil
%   d:  Retardo puro
%   
% Construye las matrices de datos de entrada y salida a un MLP tipo TDNN
%
%   ud = [...,  u(:,k-d),    ...
%               u(:,k-1-d)
%               u(:,k-2-d)
%               :
%               u(:,k-MA-d)
%               :
%               y(:,k-1)
%               y(:,k-2)
%               :
%               y(:,k-AR)   ... ]
%
%   yd = [...   y(:,k)      ... ]
%

%   Copyright (c) 2007, by 
%   Grupo de Supervisin y Diagnstico de Procesos Industriales
%   Area de Ingeniera de Sistemas y Automtica
%   Universidad de Oviedo
%   Contributed files may contain copyrights of their own.
%   
%   UniOviSOM toolbox is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.
% 
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
% 
%   You should have received a copy of the GNU General Public License
%   along with this program; if not, write to the Free Software
%   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.


if nargin<5
    d = 0;
end
    

if ~iscell(AR)
    if length(AR)==1
        AR = num2cell(1:AR);
    end
end
if ~iscell(MA)
    if length(MA)==1
        MA = num2cell(0:MA);
    end
end



l_ar = length(AR);
l_ma = length(MA);
max_ar = max(cell2mat(AR));
max_ma = max(cell2mat(MA));

N = size(u,2);
idx = max([max_ar max_ma+d])+1:N;

ud = [];

for k = 1:l_ma
    ud = [ud;u(:,idx-MA{k}-d)];
end

for k = 1:l_ar
    ud = [ud;y(:,idx-AR{k})];
end

yd = y(:,idx);

