function h = uniscatter(p,pcolor,psize);
% UNISCATTER: Scatter plot
%
%      h = uniscatter(p,pcolor,psize);
%
%      p: 2D vector of points (2xN)
% pcolor: 1D array of color values (1xN)
%  psize: 1D array with size values (1xN)
%
%  Description:
%   Draws a scatter plot of the data using squares of size 'psize' 
%   and color 'pcolor' using the default colormap
%


%   Copyright (c) 2007, by 
%   Grupo de Supervisin y Diagnstico de Procesos Industriales
%   Area de Ingeniera de Sistemas y Automtica
%   Universidad de Oviedo
%   Contributed files may contain copyrights of their own.
%   
%   UniOviSOM toolbox is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.
% 
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
% 
%   You should have received a copy of the GNU General Public License
%   along with this program; if not, write to the Free Software
%   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

clf;
N = size(p,2);

if nargin==1
    pcolor = 0*ones(1,N);
    psize = ones(1,N)*0.1;    
elseif nargin==2
    psize = ones(1,N)*0.1;
else
    if length(psize)>1
        psize = normalize_data('mnmx',psize)*0.1;
        psize = psize-min(psize)+0.01;
    else
        psize = psize*ones(1,N);
    end
end

scalex = (max(p(1,:))-min(p(1,:)))*0.1;
scaley = (max(p(2,:))-min(p(2,:)))*0.1;

% Coordenadas de los rectangulos (puntos del scatter)
% Como puede verse en patchx y patchy se almacenan los valores x e y
% de estas coordenadas, lo que produce las cuatro esquinas de cada 
% cuadrado (0,0), (1,0), (1,1) y (0,1)
patchx = ([0 1 1 0]'-0.5)*psize*scalex;
patchy = ([0 0 1 1]'-0.5)*psize*scaley;

% Se dibuja cada rectangulo utilizando la funcion patch()
h = patch(patchx+ones(4,1)*p(1,:),patchy+ones(4,1)*p(2,:),pcolor);
set(h,'linestyle','none');
colorbar;

