function varplot(p,labels,plottype)
% VARPLOT Dibuja caracteristicas respecto al tiempo
%
%       p: Matriz de datos (RxQ) por columnas
%  labels: {1xR} cell array con etiquetas para las R caracteristicas
%
% DESCRIPCION
%   Dibuja en R graficos la evolucion de caracteristicas frente al tiempo.
%   Admite diversas variedades de trazados segun plottype:
%
%   'plot': Traza las R variables sendos ejes tipo subplot
%    'alt': Traza todo en un eje para poder hacer zooms conjuntos
%  'image': Dibuja las R variables usando el mapa de color por defecto frente al tiempo
% 'imnorm': Identico a 'image' pero usando un rango del mapa de color de -1 a +1
%
% VER TAMBIEN
%   tablelens, 

%   Copyright (c) 2007, by 
%   Grupo de Supervisin y Diagnstico de Procesos Industriales
%   Area de Ingeniera de Sistemas y Automtica
%   Universidad de Oviedo
%   Contributed files may contain copyrights of their own.
%   
%   UniOviSOM toolbox is free software; you can redistribute it and/or modify
%   it under the terms of the GNU General Public License as published by
%   the Free Software Foundation; either version 2 of the License, or
%   (at your option) any later version.
% 
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
% 
%   You should have received a copy of the GNU General Public License
%   along with this program; if not, write to the Free Software
%   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.


clf;

[R,N] = size(p);


t = 1:N;
if nargin==1
    for k = 1:R
        labels{k} = strcat('Var. ',num2str(k));
    end
    plottype='plot';
elseif nargin==2
    plottype='plot';
end



% FONTSIZE
if R>20
    fontsize = 6;
elseif R>10
    fontsize = 8;
else
    fontsize = 10;
end


% TRAZADO DE LOS DATOS
if strncmp(plottype,'plot',4)
    for k = 1:R
        subplot(R,1,k);
        plot(t,p(k,:));
        xticks = get(gca,'xtick');
        yticks = get(gca,'ytick');
        text(xticks(end),(yticks(end)+yticks(1))/2,strcat('::',labels{k}),'fontsize',fontsize,'horizontalalignment','left');
        set(gca,'fontsize',fontsize);
        if k<R
            set(gca,'xticklabel',[]);
        end
        grid on;
    end
    
    % AJUSTE DE LOS SUBPLOTS PARA MAXIMIZAR EL ESPACIO OCUPADO
    for k=1:R
        subplot(R,1,k);
        posicion(k,:) = get(gca,'position');
    end
    
    dy = abs(diff(posicion(1:2,2)))*0.95;
    
    for k=1:R
        subplot(R,1,k);
        posicion(k,4) = dy;
        set(gca,'position',posicion(k,:));
    end
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    

    
elseif strncmp(plottype,'alt',3)
    pn = normalize_data('mnmx',p);
    for k = 1:R        
        ypos = R-k+1;
        plot(t,pn(k,:)*0.4+ypos);
        hold on;
        grid on;
    end
    hold off;
    set(gca,'xticklabel',[]);
    set(gca,'ytick',1:R,'yticklabel',labels(R-(1:R)+1),'fontsize',8);    
    set(gca,'position',[0.1 0.1 0.7 0.8]);
    
elseif strncmp(plottype,'image',5)
    imagesc(p);
    colorbar;
    set(gca,'ytick',1:R,'yticklabel',labels,'fontsize',8);
    % set(gca,'pos',[0.1 0.1 0.7 0.8]);
    
elseif strncmp(plottype,'imnorm',6)
    imagesc(p,[-1 1]);
    colorbar;
    set(gca,'ytick',1:R,'yticklabel',labels,'fontsize',8);
    % set(gca,'pos',[0.1 0.1 0.7 0.8]);
end



    

    


figure(gcf);
drawnow;





